@@ -2,6 +2,8 @@
 #' @description Present since \code{hutils v1.2.0}. Alias for \code{if (!requireNamespace(pkg, quietly = TRUE))} \emph{yes} \code{else} \emph{no}.
 #' Typical use-case would be \code{RQ(pkg, install.packages("pkg"))].}
 #' 
+#' Default values for \code{yes} and \code{no} from \code{hutils v1.5.0}.
+#' 
 #' This function is not recommended for use in scripts as it is a bit cryptic; its 
 #' use-case is for bash scripts and the like where calls like this would otherwise
 #' be frequent and cloud the message.
@@ -19,12 +21,12 @@
 #' 
 #' 
 
-RQ <- function(pkg, yes, no) {
+RQ <- function(pkg, yes = NULL, no = NULL) {
   .pkg <- as.character(substitute(pkg))
   stopifnot(length(.pkg) == 1L)
   if (!requireNamespace(.pkg, quietly = TRUE)) {
     yes
-  } else if (!missing(no)) {
+  } else {
     no
   }
 }
